/*!
 * \file	sccp_devstate.h
 * \brief       SCCP device state Header
 * \author	Marcello Ceschia <marcelloceschia [at] users.sourceforge.net>
 * \note	This program is free software and may be modified and distributed under the terms of the GNU Public License.
 *		See the LICENSE file at the top of the source tree.
 * \since	2013-08-15
 *
 * $Date$
 * $Revision$  
 */

#ifndef SCCP_DEVSTATE_H_
#define SCCP_DEVSTATE_H_

#include <config.h>
#include "common.h"

void sccp_devstate_module_start(void);
void sccp_devstate_module_stop(void);

#endif							/* SCCP_DEVSTATE_H_ */ 
